@@ -75,7 +75,7 @@ func ExtractFromDMG(i *info.Info, dmgPath, destPath string, arches []string, dri
 		defer func() {
 			utils.Indent(log.Debug, 2)(fmt.Sprintf("Unmounting %s", dmgPath))
 			if err := utils.Retry(3, 2*time.Second, func() error {
-				return utils.Unmount(mountPoint, false)
+				return utils.Unmount(mountPoint, true)
 			}); err != nil {
 				log.Errorf("failed to unmount DMG %s at %s: %v", dmgPath, mountPoint, err)
 			}
